==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/docking/translations/docking_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start minimized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show tooltip over tray icon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tray icon indicating new message</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Descriptions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Silent mode</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/docking/translations/docking_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start minimized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show tooltip over tray icon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tray icon indicating new message</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DockingMenuHandler</name>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Silent mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
